import React, { useState, useEffect } from "react";
import { useParams, useNavigate } from "react-router-dom";

const UserDetails = () => {
  const { id } = useParams();
  const navigate = useNavigate();

  const [users, setUsers] = useState([]);

  useEffect(() => {
    const storedUsers = JSON.parse(localStorage.getItem("users")) || [];
    setUsers(storedUsers);
  }, []);

  useEffect(() => {
    localStorage.setItem("users", JSON.stringify(users));
  }, [users]);

  const userId = parseInt(id, 10); 
  const user = users.find((user) => user.id === userId);

  const handleDelete = () => {
    const updatedUsers = users.filter((user) => user.id !== userId);
    setUsers(updatedUsers);
    alert(`User with ID ${id} deleted.`);
    navigate("/"); 
  };

  if (!user) {
    return (
      <div>
        <p>User not found.</p>
        <button onClick={() => navigate("/")}>Return to Home</button>
      </div>
    );
  }

  return (
    <div className="container">
      <h1>User Details</h1>
      <div className="user-detail">
        <p>
          <strong>Name:</strong> {user.name}
        </p>
        <p>
          <strong>Email:</strong> {user.email}
        </p>
        <p>
          <strong>Phone:</strong> {user.phone}
        </p>
        <p>
          <strong>Website:</strong> {user.website}
        </p>
      </div>
      <div className="button-container">
        <button className="home-button" onClick={() => navigate("/")}>
          Return to Home
        </button>
        <button className="delete-button" onClick={handleDelete}>
          Delete User
        </button>
      </div>
    </div>
  );
};

export default UserDetails;
